require 'spec_helper'

describe Poodle do
  it 'has a version number' do
    expect(Poodle::VERSION).not_to be nil
  end

  it 'creates a new instance of Poodle::Blood class' do
    expect(Poodle.new(:a, :b, genotype: true)).to be_a_instance_of Poodle::Blood
  end

  it 'raises error if invalid option given to inherit' do
    expect { Poodle.new(:a, :c).inherit }.to raise_error ArgumentError
  end

  it 'raises error if invalid option given to inherit_with_rate' do
    expect { Poodle.new(:a, :c).inherit_with_rate }.to raise_error ArgumentError
  end

  it 'returns a combination in phenotype' do
    expected = ["AB", "A", "B", "O"]
    expect(Poodle.new(:a, :b).inherit).to eql(expected)
  end

  it 'returns a combination in genotype' do
    expected = ["AB", "AO", "BO", "OO"]
    expect(Poodle.new(:a, :b, genotype: true).inherit).to eql(expected)
  end

  it 'returns a combination with rate in phenotype' do
    expected = {"AB"=>0.5625, "A"=>0.1875, "B"=>0.1875, "O"=>0.0625}
    expect(Poodle.new(:a, :b).inherit_with_rate).to eql(expected)
  end

  it 'retunr a combination with rate in genotype' do
    expected = {"AB"=>0.5625, "AO"=>0.1875, "BO"=>0.1875, "OO"=>0.0625} 
    expect(Poodle.new(:a, :b, genotype: true).inherit_with_rate).to eql(expected)
  end
end
